@@ -1,4 +1,4 @@
-/*	$Id: Class1.h,v 1.22 2004/06/18 20:50:48 lhoward Exp $ */
+/*	$Id: Class1.h,v 1.24 2004/09/20 19:18:05 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -56,7 +56,7 @@ protected:
     u_int	frameSize;		// size of image frames
     u_int	signalRcvd;		// last signal received in ECM protocol
     u_int	nonV34br;		// modemParams.br without V.34
-    bool	sentERR;		// whether or not ERR was sent
+    bool	sendERR;		// T.30-A send ERR instead of MCF
     bool	hadV34Trouble;		// indicates failure due to V.34 restrictions
     bool	batchingError;		// indicates failure due to batching protocol
     const u_char* frameRev;		// HDLC frame bit reversal table
@@ -212,6 +212,7 @@ public:
     bool	recvPage(TIFF*, u_int& ppm, fxStr& emsg, const fxStr& id);
     bool	recvEnd(fxStr& emsg);
     void	recvAbort();
+    void	pokeConfig();
 
 // polling support
     bool	requestToPoll(fxStr&);
