@@ -1,4 +1,4 @@
-/*	$Id: FaxAcctInfo.h,v 1.2 1999/06/13 07:41:02 robert Exp $ */
+/*	$Id: FaxAcctInfo.h,v 1.4 2004/03/17 18:26:52 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -43,6 +43,9 @@ struct FaxAcctInfo {
     u_int	npages;		// pages successfully sent/rcvd
     u_int	params;		// encoded transfer parameters
     const char*	status;		// status info (optional)
+    const char*	cidname;	// caller id name
+    const char*	cidnumber;	// caller id number
+    const char* owner;		// job owner (uid)
 
     bool record(const char* cmd) const;
 };
