@@ -1,4 +1,4 @@
-/*	$Id: FaxMachineInfo.h,v 1.4 2003/02/09 02:22:48 darren Exp $ */
+/*	$Id: FaxMachineInfo.h,v 1.7 2004/04/19 18:44:52 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -49,10 +49,12 @@ private:
     fxStr	file;			// pathname to info file
     u_int	locked;			// bit vector of locked items
     bool	changed;		// changed since restore
-    bool	supportsHighRes;	// capable of 7.7 line/mm vres
+    u_short	supportsVRes;		// VR support bitmask
     bool	supports2DEncoding;	// handles Group 3 2D
     bool	supportsMMR;		// handles Group 4
+    bool	hasV34Trouble;		// has difficulty with V.34
     bool	supportsPostScript;	// handles Adobe NSF protocol
+    bool	supportsBatching;	// handles batching (EOM) protocol
     bool	calledBefore;		// successfully called before
     u_short		maxPageWidth;		// max capable page width
     u_short		maxPageLength;		// max capable page length
@@ -88,10 +90,12 @@ public:
     virtual void writeConfig();
     virtual void resetConfig();
 
-    bool getSupportsHighRes() const;
+    u_short getSupportsVRes() const;
     bool getSupports2DEncoding() const;
     bool getSupportsMMR() const;
+    bool getHasV34Trouble() const;
     bool getSupportsPostScript() const;
+    bool getSupportsBatching() const;
     bool getCalledBefore() const;
     u_short getMaxPageWidthInPixels() const;
     u_short getMaxPageWidthInMM() const;
@@ -105,10 +109,12 @@ public:
     const fxStr& getLastSendFailure() const;
     const fxStr& getLastDialFailure() const;
 
-    void setSupportsHighRes(bool);
+    void setSupportsVRes(int);
     void setSupports2DEncoding(bool);
     void setSupportsMMR(bool);
+    void setHasV34Trouble(bool);
     void setSupportsPostScript(bool);
+    void setSupportsBatching(bool);
     void setCalledBefore(bool);
     void setMaxPageWidthInPixels(int);
     void setMaxPageLengthInMM(int);
@@ -129,14 +135,18 @@ public:
     const fxStr& getPagerSetupCmds() const;
 };
 
-inline bool FaxMachineInfo::getSupportsHighRes() const
-    { return supportsHighRes; }
+inline u_short FaxMachineInfo::getSupportsVRes() const
+    { return supportsVRes; }
 inline bool FaxMachineInfo::getSupports2DEncoding() const
     { return supports2DEncoding; }
 inline bool FaxMachineInfo::getSupportsMMR() const
     { return supportsMMR; }
+inline bool FaxMachineInfo::getHasV34Trouble() const
+    { return hasV34Trouble; }
 inline bool FaxMachineInfo::getSupportsPostScript() const
     { return supportsPostScript; }
+inline bool FaxMachineInfo::getSupportsBatching() const
+    { return supportsBatching; }
 inline bool FaxMachineInfo::getCalledBefore() const	
     { return calledBefore; }
 inline u_short FaxMachineInfo::getMaxPageWidthInPixels() const
