@@ -1,4 +1,4 @@
-/*	$Id: FaxServer.h,v 1.12 2004/06/28 19:23:56 lhoward Exp $ */
+/*	$Id: FaxServer.h,v 1.14 2004/11/16 14:55:04 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -52,6 +52,7 @@ private:
     fxStr	recvTSI;		// sender's TSI
     fxStr	hostname;		// host on which fax is received
     u_int	recvPages;		// count of received pages
+    pid_t	waitNotifyPid;		// pid of last notification process
 // send+receive stats
     time_t	connTime;		// time connected to peer
     time_t	fileStart;		// starting time for file transmit
@@ -91,7 +92,7 @@ protected:
     void	setLocalIdentifier(const fxStr& lid);
 
     void	sendFax(FaxRequest&, FaxMachineInfo&, FaxAcctInfo&, u_int&);
-    bool	recvFax(const CallerID& cid);
+    bool	recvFax(const CallerID& cid, fxStr& emsg);
 
     time_t	getFileTransferTime() const;
     time_t	getPageTransferTime() const;
