@@ -1,4 +1,4 @@
-/*	$Id: Job.h,v 1.4 2003/06/16 21:05:53 darren Exp $ */
+/*	$Id: Job.h,v 1.5 2004/08/30 18:26:03 lhoward Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -128,10 +128,16 @@ public:
     Modem*	modem;		// modem/server currently assigned to job
     QLink	triggers;	// waiting specifically on this job
 
+    Job*	bprev;		// prev in batch
+    Job*	bnext;		// next in batch
+    FaxRequest*	breq;		// pointer to request used by batching support
+
     Job(const FaxRequest&);
     void update(const FaxRequest& req);
     ~Job();
 
+    void remove(void);
+
     static Job* getJobByID(const fxStr& jobid);
     static fxStr jobStatusName(const JobStatus);
 
@@ -145,6 +151,8 @@ public:
     void startSend(pid_t pid);
 
     void encode(fxStackBuffer&) const;	// encode in JobExt format
+
+    Job* bfirst();			// first job in batch
 };
 
 /*
