@@ -1,4 +1,4 @@
-/*	$Id: Modem.h,v 1.5 2003/02/09 02:22:50 darren Exp $ */
+/*	$Id: Modem.h,v 1.7 2003/11/20 14:46:13 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -35,18 +35,18 @@
 typedef	unsigned int ModemState;
 
 class UUCPLock;
-class RegEx;
-class RegExDict;
+class RE;
+class REDict;
 class fxStackBuffer;
 class Modem;
 
 class ModemGroup {
 private:
-    static RegExDict* classes;	// registered modem classes
+    static REDict* classes;	// registered modem classes
 public:
     static void reset();
-    static void set(const fxStr& name, RegEx* re);
-    static RegEx* find(const char* name);
+    static void set(const fxStr& name, RE* re);
+    static RE* find(const char* name);
 };
 
 /*
@@ -126,6 +126,7 @@ public:
     bool supports2D() const;		// modem supports 2D-encoded fax
     bool supportsMMR() const;		// modem supports 2D-MMR encoding
     bool supportsVRes(float) const;	// modem supports vertical resolution
+    bool supportsVR(u_int) const;	// modem supports VR setting
     // modem support fax page width
     bool supportsPageWidthInMM(u_int) const;
     bool supportsPageWidthInPixels(u_int) const;
