@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.33 2004/06/01 21:34:40 lhoward Exp $ */
+/*	$Id: ModemConfig.h,v 1.35 2005/01/01 21:27:15 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -102,12 +102,14 @@ public:
     fxStr	ringFax;		// fax call ring string
     fxStr	ringVoice;		// voice call ring string
     fxStr	ringExtended;		// extended ring
+    fxStr	dringOn;		// pattern for distinctive ring silence interval
+    fxStr	dringOff;		// pattern for distinctive ring ring interval
+    bool	noAnswerVoice;		// leave voice calls unanswered
 					// caller id
     fxStr	cidName;		// pattern for name info
     fxStr	cidNumber;		// pattern for number info
     u_int	cidNameAnswerLength;	// answer when CID received
     u_int	cidNumberAnswerLength;	// answer when CID received
-
 					// protocol timers
     u_int	t1Timer;		// T.30 T1 timer (ms)
     u_int	t2Timer;		// T.30 T2 timer (ms)
@@ -135,6 +137,7 @@ public:
     u_int	class1SendMsgDelay;	// delay (ms) after training
     u_int	class1TrainingRecovery;	// delay (ms) after failed training
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
+    u_int	class1Resolutions;	// resolutions support
     u_int	class1FrameOverhead;	// overhead bytes in received frames
     u_int	class1RecvIdentTimer;	// timeout receiving initial identity
     u_int	class1TCFMaxNonZero;	// non-zero threshold for TCF check
@@ -143,7 +146,6 @@ public:
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
     bool	class1ECMSupport;	// support T.30-A ECM
     bool	class1PersistentECM;	// continue to correct
-    bool	class1ExtendedRes;	// support for extended resolutions
     bool	class1TCFRecvHack;	// deliberately look for V.21 disconnect
     bool	class1ValidateV21Frames;// check received FCS values in V.21
 					// for class 2 and 2.0:
@@ -209,9 +211,19 @@ public:
     RTNHandling rtnHandling;            // RTN signal handling method
     bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
     
+    					// Distinctive ring data as sequences of DRON/DROF intervals
+    struct {
+    	int cadence[5];                 // the ring cadence as a five-dimensional vector
+	double magsqrd;               	// magnitude of the vector squared
+	u_int type;                     // call type of voice, fax, or data
+    } distinctiveRings[5];              // up to 5 distinctive ring numbers
+    u_int NoDRings;                     // number of distinctive rings numbers found
+
         virtual ~ModemConfig();
 
     void parseCID(const char*, CallerID&) const;
     const fxStr& getFlowCmd(FlowControl) const;
+    void parseDR(const char*);
+    void processDRString(char*, const u_int);
 };
 #endif /* _ModemConfig_ */
