@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.4 2002/10/18 19:08:28 darren Exp $ */
+/*	$Id: ModemServer.h,v 1.8 2004/06/01 21:34:42 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -83,6 +83,9 @@ private:
 // buffered i/o stuff
     short	rcvCC;			// # bytes pending in rcvBuf
     short	rcvNext;		// next available byte in rcvBuf
+    u_short	rcvBit;			// pending bit of rcvNext to send
+    int		gotByte;		// byte held for bit destruction
+    bool	sawBlockEnd;		// whether DLE+ETX has been seen
     u_char	rcvBuf[1024];		// receive buffering
 
     friend class ClassModem;
@@ -124,6 +127,7 @@ protected:
 
 // modem driver setup+teardown interfaces
     virtual bool setupModem();
+    virtual bool readyModem();
     virtual void discardModem(bool dropDTR);
     virtual ClassModem* deduceModem();
 // low-level modem interfaces
@@ -134,6 +138,10 @@ protected:
     void	timerExpired(long, long);
     int		getModemLine(char buf[], u_int bufSize, long ms = 0);
     int		getModemChar(long ms = 0);
+    int		getModemBit(long ms = 0);
+    int		getLastByte();
+    bool	didBlockEnd();
+    void	resetBlock();
     bool	isModemInput() const;
     void	flushModemInput();
     bool	putModem(const void* data, int n, long ms = 0);
@@ -150,8 +158,8 @@ protected:
     bool	setInputBuffering(bool on);
     bool	modemStopOutput();
 // modem driver interfaces
-    bool	modemWaitForRings(u_int rings, CallType&, CallerID&);
-    CallType	modemAnswerCall(AnswerType, fxStr&);
+    bool	modemWaitForRings(u_short rings, CallType&, CallerID&);
+    CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL);
     void	modemAnswerCallCmd(CallType);
     void	modemFlushInput();
     void	modemHangup();
