@@ -1,4 +1,4 @@
-/* $Id: NSF.h,v 1.3 2000/10/29 11:41:10 darren Exp $ */
+/* $Id: NSF.h,v 1.5 2004/05/22 02:12:36 lhoward Exp $ */
 /* 
  * This file does not exist in the original HylaFAX distribution.
  * Created by Dmitry Bely, April 2000
@@ -43,7 +43,7 @@ class NSF {
     bool  stationIdDecoded;
 public:
     NSF();
-    NSF( const char* hexNSF );
+    NSF( const char* hexNSF, bool useHex );
     NSF( const u_char* rawData, int size, const u_char* revTab );
     /*
      * We are happy with default copy constructor and copy assignment,
@@ -58,9 +58,9 @@ public:
     const char* getStationId(){ return (const char*)stationId; }
 private:
     void clear();
-    void loadHexData( const char* hexNSF );
+    void loadHexData( const char* hexNSF, bool useHex );
     void loadRawData( const u_char* rawData, int size, const u_char* revTab );
-    void findStationId( bool reverseOrder );
+    void findStationId( bool reverseOrder, bool reverseBitOrder );
     void decode();
 };
 
