@@ -1,4 +1,4 @@
-/*	$Id: ServerConfig.h,v 1.4 2002/06/15 18:00:06 darren Exp $ */
+/*	$Id: ServerConfig.h,v 1.6 2004/03/05 02:41:39 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,7 +32,7 @@
 
 class DialStringRules;
 class UUCPLock;
-class RegExArray;
+class REArray;
 class fxBoolArray;
 
 class ServerConfig : public ModemConfig {
@@ -66,8 +66,11 @@ private:
     mode_t	uucpLockMode;		// UUCP lock file creation mode
     u_int	uucpLockTimeout;	// UUCP stale lock file timeout
     time_t	lastTSIModTime;		// last mod time of TSI patterns file
-    RegExArray*	tsiPats;		// recv tsi patterns
+    time_t	lastPWDModTime;		// last mod time of PWD patterns file
+    REArray*	tsiPats;		// recv tsi patterns
+    REArray*	pwdPats;		// recv PWD patterns
     fxBoolArray* acceptTSI;		// accept/reject matched tsi
+    fxBoolArray* acceptPWD;		// accept/reject matched PWD
     fxStr	logFacility;		// syslog facility to direct trace msgs
 
     static S_stringtag strings[];
@@ -83,10 +86,10 @@ protected:
 
 // pattern access control list support
     void	updatePatterns(const fxStr& file,
-		    RegExArray*& pats, fxBoolArray*& accept,
+		    REArray*& pats, fxBoolArray*& accept,
 		    time_t& lastModTime);
-    void	readPatterns(FILE*, RegExArray*&, fxBoolArray*&);
-    bool	checkACL(const fxStr& id, RegExArray*, fxBoolArray&);
+    void	readPatterns(FILE*, REArray*&, fxBoolArray*&);
+    bool	checkACL(const fxStr& id, REArray*, fxBoolArray&);
 // methods for parameters whose assignment may have side effects
     virtual void setDialRules(const char* name);
     virtual void setLocalIdentifier(const fxStr& lid);
@@ -94,6 +97,7 @@ protected:
 public:
     SpeakerVolume speakerVolume;	// volume control
     fxStr	qualifyTSI;		// if set, no recv w/o acceptable tsi
+    fxStr	qualifyPWD;		// if set, no recv w/o acceptable PWD
     u_int	noCarrierRetrys;	// # times to retry on no carrier
     mode_t	recvFileMode;		// protection mode for received files
     mode_t	deviceMode;		// protection mode for modem device
@@ -124,6 +128,7 @@ public:
     UUCPLock*	getUUCPLock(const fxStr& deviceName);
 
     bool	isTSIOk(const fxStr& tsi);
+    bool	isPWDOk(const fxStr& pwd);
 
     virtual void vconfigError(const char* fmt, va_list ap) = 0;
     virtual void vconfigTrace(const char* fmt, va_list ap) = 0;
