@@ -1,4 +1,4 @@
-/*	$Id: faxQueueApp.h,v 1.10 2004/04/19 18:44:53 lhoward Exp $ */
+/*	$Id: faxQueueApp.h,v 1.11 2004/08/30 18:26:04 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -196,6 +196,7 @@ private:
 		    DestInfo&, const DestControlInfo&);
     void	sendJobStart(Job&, FaxRequest*, const DestControlInfo&);
     void	sendJobDone(Job& job, int status);
+    void	sendJobDone(Job& job, FaxRequest* req, int status);
     void	blockJob(Job&, FaxRequest&, const char*);
     void	delayJob(Job&, FaxRequest&, const char*, time_t);
     void	rejectJob(Job& job, FaxRequest& req, const fxStr& reason);
@@ -221,7 +222,7 @@ private:
 // job preparation stuff
     bool	prepareJobNeeded(Job&, FaxRequest&, JobStatus&);
     static void prepareCleanup(int s);
-    void	prepareJobStart(Job&, FaxRequest*,
+    bool	prepareJobStart(Job&, FaxRequest*,
 		    FaxMachineInfo&, const DestControlInfo&);
     void	prepareJobDone(Job&, int status);
     JobStatus	prepareJob(Job& job, FaxRequest& req,
