@@ -1,4 +1,4 @@
-/*	$Id: manifest.h,v 1.1.1.1 1998/10/12 20:47:50 root Exp $ */
+/*	$Id: manifest.h,v 1.2 2004/02/28 18:54:21 lhoward Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -45,15 +45,6 @@
 #endif
 #define	FAXUID_ANON	FAXUID_MAX	// UID of anonymous user
 
-/*
- * Sequence numbers are assigned for jobs and documents
- * stored in the fax filesystem.  We constrain these
- * numbers to be 16-bit values, rolling them over a bit
- * early (for historical reasons).
- */
-#define	MAXSEQNUM	32000		// safely fits in 16 bits
-#define	NEXTSEQNUM(x)	((x) % MAXSEQNUM)
-
 /*
  * The client-server protocol is derived from the Internet
  * File Transfer Protocol (FTP).  We extend two FTP notions,
