@@ -1,4 +1,4 @@
-/*	$Id: Class2Params.h,v 1.3 2002/05/23 21:09:24 darren Exp $ */
+/*	$Id: Class2Params.h,v 1.6 2004/03/05 02:29:43 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -36,10 +36,10 @@ private:
 // XXX these exist solely for FaxModem
     static const char* pageWidthNames[8];
     static const char* pageLengthNames[4];
-    static const char* verticalResNames[2];
+    static const char* verticalResNames[65];
     static const char* scanlineTimeNames[8];
     static const char* dataFormatNames[4];
-    static const char* ecmNames[4];
+    static const char* ecmNames[8];
 
     friend class FaxModem;
 public:
@@ -75,7 +75,7 @@ public:
     int operator==(const Class2Params&) const;
     int operator!=(const Class2Params&) const;
 
-    fxStr cmd(bool class2UseHex) const;		// format AT+F cmd string
+    fxStr cmd(bool class2UseHex, bool ecm20 = false) const;	// format AT+F cmd string
     void setFromDIS(u_int dis, u_int xinfo = 0);
     void setFromDCS(u_int dcs, u_int xinfo = 0);
     u_int getDCS() const;
@@ -91,7 +91,9 @@ public:
     u_int pageLength() const;		// page length in mm
     void setPageLengthInMM(u_int l);
     u_int verticalRes() const;		// lines/inch
-    void setVerticalRes(u_int res);
+    u_int horizontalRes() const;	// dpi
+    void setRes(u_int xres, u_int yres);
+    u_int getMinSpeed() const;
 
     static const char* bitRateNames[16];	// XXX needed by Class 1 driver
 
@@ -100,6 +102,7 @@ public:
     const char* bitRateName() const;
     u_int bitRate() const;		// bits/second value
     const char* verticalResName() const;
+    const char* bestVerticalResName() const;
     const char* scanlineTimeName() const;
     const char* dataFormatName() const;
     const char* ecmName() const;
