@@ -1,4 +1,4 @@
-/*	$Id: FaxClient.h,v 1.4 2002/06/15 18:00:11 darren Exp $ */
+/*	$Id: FaxClient.h,v 1.5 2003/02/08 22:49:56 darren Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -84,7 +84,7 @@ public:
     struct FaxParam {
         const char* cmd;
         const char** parmNames;
-        int	NparmNames;
+        u_int	NparmNames;
         u_int	FaxClient::*pv;
     };
     struct FaxFmtHeader {
