@@ -1,4 +1,4 @@
-/*	$Id: StackBuffer.h,v 1.4 2002/07/06 17:52:52 darren Exp $ */
+/*	$Id: StackBuffer.h,v 1.8 2003/04/26 07:11:22 robert Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -54,12 +54,8 @@ public:
     u_int getLength() const;		// Return number of bytes in buffer
 
     // NB: the buffer is *NOT* null terminated, unless you put one there.
-    // the operator char*() removed by rjc 8/99 as causes gcc-2.95 problems
-    // the operator char*() un-removed 7/02 for buffer checking
-    operator char*();			// Return base of buffer
-    operator unsigned char*();		// Return base of buffer
     operator const char*() const;	// Return base of buffer
-    operator const unsigned char*() const;// Return base of buffer
+    operator const u_char*() const;// Return base of buffer
     char& operator[](u_int i) const;	// Return character in buffer
     char& operator[](int i) const;	// Return character in buffer
     fxStackBuffer& operator=(const fxStackBuffer&);
@@ -79,12 +75,10 @@ inline void fxStackBuffer::put(char c)
 inline void fxStackBuffer::put(char const* c)	{ put(c, strlen(c)); }
 inline void fxStackBuffer::set(char c)		{ put(c); next--; }
 inline void fxStackBuffer::reset()		{ next = base; }
-inline fxStackBuffer::operator char*()		{ return base; }
-inline fxStackBuffer::operator unsigned char*()	{ return (unsigned char*)base; }
 inline fxStackBuffer::operator const char*() const
     { return base; }
-inline fxStackBuffer::operator const unsigned char*() const
-    { return (unsigned char*)base; }
+inline fxStackBuffer::operator const u_char*() const
+    { return (u_char*)base; }
 inline u_int fxStackBuffer::getLength() const	{ return next - base; }
 inline char& fxStackBuffer::operator[](u_int ix) const { return base[ix]; }
 inline char& fxStackBuffer::operator[](int ix) const   { return base[ix]; }
