@@ -1,4 +1,4 @@
-/*	$Id: class2.h,v 1.4 2003/02/08 22:49:59 darren Exp $ */
+/*	$Id: class2.h,v 1.8 2004/03/29 18:57:52 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -53,16 +53,15 @@ const u_short SERVICE_VOICE	 = BIT(8);	// voice service (ZyXEL extension)
 const u_short SERVICE_ALL	 = BIT(9)-1;
 
 // t.30 session subparameter codes
-// NB: only the first two are used
-const u_int VR_NORMAL	= 0;		// 98 lpi
-const u_int VR_FINE	= 1;		// 196 lpi
-const u_int VR_R8		= 2;		// R8  x 15.4 l/mm
-const u_int VR_R16	= 4;		// R16 x 15.4 l/mm
-const u_int VR_200X100	= 8;		// 200 dpi x 100 l/25.4mm
-const u_int VR_200X200	= 10;		// 200 dpi x 200 l/25.4mm
-const u_int VR_200X400	= 20;		// 200 dpi x 400 l/25.4mm
-const u_int VR_300X300	= 40;		// 300 dpi x 300 l/25.4mm
-const u_int VR_ALL	= BIT(VR_FINE+1)-1;
+const u_int VR_NORMAL	= 0x00;		// 98 lpi
+const u_int VR_FINE	= 0x01;		// 196 lpi
+const u_int VR_R8	= 0x02;		// R8  x 15.4 l/mm
+const u_int VR_R16	= 0x04;		// R16 x 15.4 l/mm
+const u_int VR_200X100	= 0x08;		// 200 dpi x 100 l/25.4mm
+const u_int VR_200X200	= 0x10;		// 200 dpi x 200 l/25.4mm
+const u_int VR_200X400	= 0x20;		// 200 dpi x 400 l/25.4mm
+const u_int VR_300X300	= 0x40;		// 300 dpi x 300 l/25.4mm
+const u_int VR_ALL	= 0x7F;
 
 const u_short BR_2400	= 0;		// 2400 bit/s
 const u_short BR_4800	= 1;		// 4800 bit/s
@@ -94,17 +93,22 @@ const u_short LN_ALL	= BIT(LN_INF+1)-1;
 
 const u_short LN_LET	= 3;		// XXX US Letter size (used internally)
 
-const u_short DF_1DMR	= 0;		// 1-D Modified Huffman
-const u_short DF_2DMR	= 1;		// 2-D Modified Huffman
+const u_short DF_1DMH	= 0;		// 1-D Modified Huffman
+const u_short DF_2DMR	= 1;		// 2-D Modified Read
 const u_short DF_2DMRUNCOMP	= 2;		// 2-D Uncompressed Mode
 const u_short DF_2DMMR	= 3;		// 2-D Modified Modified Read
 const u_short DF_ALL	= BIT(DF_2DMMR+1)-1;
 
+/*
+ * The EC definition varies between the Class 2 and Class 2.0 spec, so
+ * this is a merger of both of them.
+ */
 const u_short EC_DISABLE	= 0;		// disable ECM
-const u_short EC_ENABLE	= 1;		// enable T.30 Annex A, ECM
-const u_short EC_ECLHALF	= 2;		// enable T.30 Annex C, half duplex
-const u_short EC_ECLFULL	= 3;		// enable T.30 Annex C, full duplex
-const u_short EC_ALL	= 0x3;
+const u_short EC_ENABLE64	= 1;		// enable T.30 Annex A, 64-byte ECM
+const u_short EC_ENABLE256	= 2;		// enable T.30 Annex A, 256-byte ECM
+const u_short EC_ECLHALF	= 3;		// enable T.30 Annex C, half duplex
+const u_short EC_ECLFULL	= 4;		// enable T.30 Annex C, full duplex
+const u_short EC_ALL		= BIT(EC_ECLFULL+1)-1;
 
 const u_short BF_DISABLE	= 0;		// disable file transfer modes
 const u_short BF_ENABLE	= 1;		// select BFT, T.434
@@ -149,4 +153,5 @@ const int ETX = 3;		// <DLE><ETX> means end of transfer
 const int DC1 = 17;		// start data transfer (Class 2)
 const int DC2 = 18;		// start data transfer (Class 2.0 and ZyXEL)
 const int CAN = 24;		// abort data transfer
+const int EOT = 4;		// end transmission (Class 1.0)		
 #endif /* _class2_ */
