@@ -1,4 +1,4 @@
-/*	$Id: t.30.h,v 1.2 2002/05/23 21:09:25 darren Exp $ */
+/*	$Id: t.30.h,v 1.7 2004/03/05 02:29:45 lhoward Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -62,6 +62,9 @@
 
 #define	TCF_DURATION	1500		// 1.5 seconds
 
+// this is our defined NSF manufacturer code in reverse bit-order
+#define HYLAFAX_NSF	"\255\000\125"
+
 /*
  * Facsimile control field (FCF) values
  */
@@ -101,6 +104,7 @@
  * minimum DIS frame;  we only process the first 4.
  */
 #define DIS_V8		0x040000	// supports V.8 training
+#define DIS_FRAMESIZE	0x020000	// preferred ECM frame size indicator
 #define	DIS_T4XMTR	0x008000	// T.4 sender & has docs to poll
 #define	DIS_T4RCVR	0x004000	// T.4 receiver
 #define	DIS_SIGRATE	0x003C00	// data signalling rate
@@ -142,7 +146,11 @@
 #define	DIS_G4COMP	(0x02<<24)	// T.6 compression supported
 // bit 0x01 indicates an extension byte follows
 
-// 2nd extension byte (alternative paper width capabilities)
+// The meaning of the 2nd extension byte changed after the 1993 recommendation.
+// If DIS_IGNOLD is set, then the 1993 definitions can be understood, otherwise
+// the current definitions should be understood.
+
+// 2nd extension byte - 1993 meaning - (alternative paper width capabilities)
 #define	DIS_IGNOLD	(0x80<<16)	// ignore old paper widths in byte 3
 #define	DIS_1216	(0x40<<16)	// 1216 pixels in 151 mm scanline
 #define	DIS_864		(0x20<<16)	// 864 pixels in 107 mm scanline
@@ -151,6 +159,16 @@
 // bits 0x04 and 0x02 are reserved
 // bit 0x01 indicates an extension byte follows
 
+// 2nd extension byte - current meaning
+// bit 0x80 is not valid and must be unset
+#define	DIS_MULTSEP	(0x40<<16)	// multiple selective polling capability
+#define	DIS_POLLSUB	(0x20<<16)	// polled subaddress
+#define	DIS_T43		(0x10<<16)	// T.43 coding
+#define	DIS_INTERLV	(0x08<<16)	// plane interleave
+#define	DIS_VOICE	(0x04<<16)	// voice coding - G.726
+#define	DIS_VOICEXT	(0x02<<16)	// extended voice coding
+// bit 0x01 indicates an extension byte follows
+
 // 3rd extension byte (alternative resolution capabilities)
 #define	DIS_200X400	(0x80<<8)	// 200 x 400 pixels/inch resolution
 #define	DIS_300X300	(0x40<<8)	// 300 x 300 pixels/inch resolution
@@ -224,7 +242,7 @@
 #define	    DCSFRAME_64		(1<<28)	// 64 octets
 #define	DCS_ELMODE	(0x08<<24)	// use error limiting mode
 // bit 0x04 is reserved for Group 4
-#define	DCS_G4COMP	0x02<<24)	// use T.6 compression
+#define	DCS_G4COMP	(0x02<<24)	// use T.6 compression
 // bit 0x01 indicates another information byte follows
 
 // 2nd extension byte (alternative paper width capabilities)
@@ -256,6 +274,7 @@
 // pre-message responses
 #define	FCF_CFR		0x21		// confirmation to receive
 #define	FCF_FTT		0x22		// failure to train
+#define FCF_CTR		0x23		// response to CTC (Annex A)
 
 // post-message commands (from transmitter to receiver)
 #define	FCF_EOM		0x71		// end-of-page, restart phase B on ack
@@ -264,6 +283,9 @@
 #define	FCF_PRI_EOM	0x79		// EOM, but allow operator intervention
 #define	FCF_PRI_MPS	0x7A		// MPS, but allow operator intervention
 #define	FCF_PRI_EOP	0x7C		// MPS, but allow operator intervention
+#define FCF_PPS		0x7D		// partial page signal (Annex A)
+#define FCF_EOR		0x73		// end of retransmission (Annex A)
+#define FCF_RR		0x76		// receive ready (Annex A), was erroniously 0x37 3/93
 
 // post-message responses (from receiver to transmitter)
 #define	FCF_MCF		0x31		// message confirmation (ack MPS/EOM)
@@ -271,8 +293,14 @@
 #define	FCF_RTN		0x32		// nak, retry after retraining
 #define	FCF_PIP		0x35		// ack, continue after operating interv.
 #define	FCF_PIN		0x34		// nak, retry after operation interv.
+#define FCF_PPR		0x3D		// partial page request (Annex A)
+#define FCF_RNR		0x37		// receive not ready (Annex A)
+#define FCF_ERR		0x38		// response for EOR (Annex A)
 
 // other line control signals
 #define	FCF_DCN		0x5F		// disconnect - initiate call release
 #define	FCF_CRP		0x58		// command repeat - resend last command
+
+// command to receive
+#define FCF_CTC		0x48		// continue to correct (Annex A)
 #endif /* _t30_ */
